@@ -18,3 +18,10 @@ class VeginerError(error):
 
 class VPadError(VeginerError): pass
 
+class GenerationTypeError(VeginerError): pass
+
+
+class SocketError(error):
+    pass
+
+class SetupError(SocketError): pass
\ No newline at end of file
